==> backup-1.93.0-sources.jar: software/amazon/awscdk/services/backup/TagCondition.java <==
package software.amazon.awscdk.services.backup;

/**
 * (experimental) A tag condition.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.24.0 (build b722f66)", date = "2021-03-11T13:46:52.309Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.backup.$Module.class, fqn = "@aws-cdk/aws-backup.TagCondition")
@software.amazon.jsii.Jsii.Proxy(TagCondition.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface TagCondition extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) The key in a key-value pair.
     * <p>
     * For example, in <code>"ec2:ResourceTag/Department": "accounting"</code>,
     * <code>ec2:ResourceTag/Department</code> is the key.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @org.jetbrains.annotations.NotNull java.lang.String getKey();

    /**
     * (experimental) The value in a key-value pair.
     * <p>
     * For example, in <code>"ec2:ResourceTag/Department": "accounting"</code>,
     * <code>accounting</code> is the value.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @org.jetbrains.annotations.NotNull java.lang.String getValue();

    /**
     * (experimental) An operation that is applied to a key-value pair used to filter resources in a selection.
     * <p>
     * Default: STRING_EQUALS
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.backup.TagOperation getOperation() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link TagCondition}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link TagCondition}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<TagCondition> {
        private java.lang.String key;
        private java.lang.String value;
        private software.amazon.awscdk.services.backup.TagOperation operation;

        /**
         * Sets the value of {@link TagCondition#getKey}
         * @param key The key in a key-value pair. This parameter is required.
         *            For example, in <code>"ec2:ResourceTag/Department": "accounting"</code>,
         *            <code>ec2:ResourceTag/Department</code> is the key.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder key(java.lang.String key) {
            this.key = key;
            return this;
        }

        /**
         * Sets the value of {@link TagCondition#getValue}
         * @param value The value in a key-value pair. This parameter is required.
         *              For example, in <code>"ec2:ResourceTag/Department": "accounting"</code>,
         *              <code>accounting</code> is the value.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder value(java.lang.String value) {
            this.value = value;
            return this;
        }

        /**
         * Sets the value of {@link TagCondition#getOperation}
         * @param operation An operation that is applied to a key-value pair used to filter resources in a selection.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder operation(software.amazon.awscdk.services.backup.TagOperation operation) {
            this.operation = operation;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link TagCondition}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public TagCondition build() {
            return new Jsii$Proxy(key, value, operation);
        }
    }

    /**
     * An implementation for {@link TagCondition}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements TagCondition {
        private final java.lang.String key;
        private final java.lang.String value;
        private final software.amazon.awscdk.services.backup.TagOperation operation;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.key = software.amazon.jsii.Kernel.get(this, "key", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.value = software.amazon.jsii.Kernel.get(this, "value", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.operation = software.amazon.jsii.Kernel.get(this, "operation", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.backup.TagOperation.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final java.lang.String key, final java.lang.String value, final software.amazon.awscdk.services.backup.TagOperation operation) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.key = java.util.Objects.requireNonNull(key, "key is required");
            this.value = java.util.Objects.requireNonNull(value, "value is required");
            this.operation = operation;
        }

        @Override
        public final java.lang.String getKey() {
            return this.key;
        }

        @Override
        public final java.lang.String getValue() {
            return this.value;
        }

        @Override
        public final software.amazon.awscdk.services.backup.TagOperation getOperation() {
            return this.operation;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("key", om.valueToTree(this.getKey()));
            data.set("value", om.valueToTree(this.getValue()));
            if (this.getOperation() != null) {
                data.set("operation", om.valueToTree(this.getOperation()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-backup.TagCondition"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            TagCondition.Jsii$Proxy that = (TagCondition.Jsii$Proxy) o;

            if (!key.equals(that.key)) return false;
            if (!value.equals(that.value)) return false;
            return this.operation != null ? this.operation.equals(that.operation) : that.operation == null;
        }

        @Override
        public final int hashCode() {
            int result = this.key.hashCode();
            result = 31 * result + (this.value.hashCode());
            result = 31 * result + (this.operation != null ? this.operation.hashCode() : 0);
            return result;
        }
    }
}

==> backup-1.182.0-sources.jar: software/amazon/awscdk/services/backup/TagCondition.java <==
package software.amazon.awscdk.services.backup;

/**
 * A tag condition.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.services.backup.*;
 * TagCondition tagCondition = TagCondition.builder()
 *         .key("key")
 *         .value("value")
 *         // the properties below are optional
 *         .operation(TagOperation.STRING_EQUALS)
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.71.0 (build f1f58ae)", date = "2022-12-07T17:24:49.254Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.backup.$Module.class, fqn = "@aws-cdk/aws-backup.TagCondition")
@software.amazon.jsii.Jsii.Proxy(TagCondition.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface TagCondition extends software.amazon.jsii.JsiiSerializable {

    /**
     * The key in a key-value pair.
     * <p>
     * For example, in <code>"ec2:ResourceTag/Department": "accounting"</code>,
     * <code>ec2:ResourceTag/Department</code> is the key.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getKey();

    /**
     * The value in a key-value pair.
     * <p>
     * For example, in <code>"ec2:ResourceTag/Department": "accounting"</code>,
     * <code>accounting</code> is the value.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getValue();

    /**
     * An operation that is applied to a key-value pair used to filter resources in a selection.
     * <p>
     * Default: STRING_EQUALS
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.backup.TagOperation getOperation() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link TagCondition}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link TagCondition}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<TagCondition> {
        java.lang.String key;
        java.lang.String value;
        software.amazon.awscdk.services.backup.TagOperation operation;

        /**
         * Sets the value of {@link TagCondition#getKey}
         * @param key The key in a key-value pair. This parameter is required.
         *            For example, in <code>"ec2:ResourceTag/Department": "accounting"</code>,
         *            <code>ec2:ResourceTag/Department</code> is the key.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder key(java.lang.String key) {
            this.key = key;
            return this;
        }

        /**
         * Sets the value of {@link TagCondition#getValue}
         * @param value The value in a key-value pair. This parameter is required.
         *              For example, in <code>"ec2:ResourceTag/Department": "accounting"</code>,
         *              <code>accounting</code> is the value.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder value(java.lang.String value) {
            this.value = value;
            return this;
        }

        /**
         * Sets the value of {@link TagCondition#getOperation}
         * @param operation An operation that is applied to a key-value pair used to filter resources in a selection.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder operation(software.amazon.awscdk.services.backup.TagOperation operation) {
            this.operation = operation;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link TagCondition}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public TagCondition build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link TagCondition}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements TagCondition {
        private final java.lang.String key;
        private final java.lang.String value;
        private final software.amazon.awscdk.services.backup.TagOperation operation;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.key = software.amazon.jsii.Kernel.get(this, "key", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.value = software.amazon.jsii.Kernel.get(this, "value", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.operation = software.amazon.jsii.Kernel.get(this, "operation", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.backup.TagOperation.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.key = java.util.Objects.requireNonNull(builder.key, "key is required");
            this.value = java.util.Objects.requireNonNull(builder.value, "value is required");
            this.operation = builder.operation;
        }

        @Override
        public final java.lang.String getKey() {
            return this.key;
        }

        @Override
        public final java.lang.String getValue() {
            return this.value;
        }

        @Override
        public final software.amazon.awscdk.services.backup.TagOperation getOperation() {
            return this.operation;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("key", om.valueToTree(this.getKey()));
            data.set("value", om.valueToTree(this.getValue()));
            if (this.getOperation() != null) {
                data.set("operation", om.valueToTree(this.getOperation()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-backup.TagCondition"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            TagCondition.Jsii$Proxy that = (TagCondition.Jsii$Proxy) o;

            if (!key.equals(that.key)) return false;
            if (!value.equals(that.value)) return false;
            return this.operation != null ? this.operation.equals(that.operation) : that.operation == null;
        }

        @Override
        public final int hashCode() {
            int result = this.key.hashCode();
            result = 31 * result + (this.value.hashCode());
            result = 31 * result + (this.operation != null ? this.operation.hashCode() : 0);
            return result;
        }
    }
}
